import type HasActionSubmitData from "../Interfaces/HasActionSubmitData";
import type IsAction from "../Interfaces/IsAction";
/**
 * Submit action
 *
 * @since 1.0.0
 */
export default class ActionSubmit implements IsAction {
    private actionData;
    private formValues;
    /**
    * Constuctor.
    *
    * @param actionData Action data.
    * @param form Form object.
    *
    * @since 1.0.0
    */
    constructor(actionData: HasActionSubmitData, formValues?: {});
    /**
     * Get headers to send.
     *
     * @returns Headers to send.
     *
     * @since 1.0.0
     */
    private getHeaders;
    /**
     * Get body to send.
     *
     * @returns Body to send.
     *
     * @since 1.0.0
     */
    private getBody;
    /**
     * Get url to send.
     *
     * @returns Url to send.
     *
     * @since 1.0.0
     */
    private getUrl;
    /**
     * Get action method.
     *
     * @returns Action method.
     *
     * @since 1.0.0
     */
    getMethod(): string;
    /**
     * Run action.
     *
     * @since 1.0.0
     */
    execute(): boolean;
    /**
     * Set error.
     *
     * @since 1.0.0
     */
    setError(): void;
    /**
     * Set success.
     *
     * @since 1.0.0
     */
    setSuccess(): void;
}
