import ActionAlert from "./ActionAlert";
import ActionCallback from "./ActionCallback";
import ActionConsole from "./ActionConsole";
import ActionModal from "./ActionModal";
import ActionNotice from "./ActionNotice";
import ActionStop from "./ActionStop";
import ActionSubmit from "./ActionSubmit";
/**
 * Actions.
 *
 * @since 1.0.0
 */
export default class Actions {
    actions = [];
    /**
     * Constructor.
     *
     * @param actionsData Actions data.
     * @param form Form instance.
     *
     * @since 1.0.0
     */
    constructor(actionsData, formValues = {}) {
        actionsData.forEach(actionData => {
            let action;
            switch (actionData.type) {
                case "alert":
                    action = new ActionAlert(actionData.data);
                    this.actions.push(action);
                    break;
                case "callback":
                    action = new ActionCallback(actionData.data);
                    this.actions.push(action);
                    break;
                case "console":
                    action = new ActionConsole(actionData.data);
                    this.actions.push(action);
                    break;
                case "modal":
                    action = new ActionModal(actionData.data);
                    this.actions.push(action);
                    break;
                case "notice":
                    action = new ActionNotice(actionData.data);
                    this.actions.push(action);
                    break;
                case "stop":
                    action = new ActionStop();
                    this.actions.push(action);
                    break;
                case "submit":
                    action = new ActionSubmit(actionData.data, formValues);
                    this.actions.push(action);
                    break;
                default:
                    throw new Error("Action type '" + actionData.type + "' does not exist.");
            }
        });
    }
    /**
     * Run all actions.
     *
     * @return boolean True if all actions were executed successfully.
     *
     * @since 1.0.0
     */
    execute() {
        let execute = true;
        this.actions.forEach(action => {
            if (execute) {
                execute = action.execute();
            }
        });
        return execute;
    }
}
