import Actions from "./Actions";
import Conditions from "../Helpers/Conditions";
/**
 * Field class.
 *
 * @since 1.0.0
 */
export default class Event {
    conditions;
    actions;
    trigger;
    /**
     * Constructor.
     *
     * @param trigger Trigger when action fires (change or submit).
     * @param conditions Conditions which have to be fullfilled to run actions after it was triggered.
     * @param actions Actions to be executed.
     *
     * @since 1.0.0
     */
    constructor(eventData, formValues = {}) {
        this.conditions = new Conditions(eventData.conditions, formValues);
        this.actions = new Actions(eventData.actions, formValues);
        this.trigger = eventData.trigger;
    }
    /**
     * Runs the event.
     *
     * @return boolean True if all actions were executed successfully.
     *
     * @since 1.0.0
     */
    execute() {
        if (!this.conditions.fullfilled()) {
            return true;
        }
        return this.actions.execute();
    }
}
