import Button from "../Helpers/Button";
/**
 * Modal class.
 *
 * @since 1.0.0
 */
export default class Modal {
    modalData;
    /**
     * Show modal.
     *
     * @param modalData Modal data.
     *
     * @since 1.0.0
     */
    constructor(modalData = null) {
        this.modalData = modalData;
    }
    /**
     * Is modal visible.
     *
     * @returns True if modal is visible, false otherwise.
     *
     * @since 1.0.0
     */
    isVisible() {
        return this.modalData !== null && this.modalData.visibility === "show";
    }
    /**
     * Modal title.
     *
     * @returns Modal title.
     *
     * @since 1.0.0
     */
    getTitle() {
        return this.modalData.title;
    }
    /**
     * Modal body.
     *
     * @returns Modal body.
     *
     * @since 1.0.0
     */
    getBody() {
        return this.modalData.body;
    }
    /**
     * Get buttons.
     *
     * @returns Modal buttons.
     *
     * @since 1.0.0
     */
    getButtons() {
        let buttons = [];
        this.modalData.buttons.forEach(buttonData => {
            buttons.push(new Button(buttonData));
        });
        return buttons;
    }
    /**
     * Hide modal.
     *
     * @since 1.0.0
     */
    dismiss() {
        this.modalData = null;
    }
    /**
     * Check if modal exists.
     *
     * @since 1.0.0
     */
    exists() {
        return this.modalData !== undefined;
    }
}
