import type HasFieldData from '../Interfaces/HasFieldData';
import Field from './Field';
/**
 * MutipleField class.
 *
 * @since 1.0.0
 */
export default class MultipleField extends Field {
    /**
     * Initializing field.
     *
     * @param fieldData  Field data.
     * @param formValues Form values.
     *
     * @since 1.0.0
     */
    constructor(fieldData: HasFieldData, formValues?: {});
    /**
     * Get values of the mutliple field.
     *
     * @returns All values of the field.
     *
     * @since 1.0.0
     */
    getValues(): any[];
    /**
    * Doing form things and get value of the field.
    *
    * @returns Value of the field.
    *
    * @since 1.0.0
    */
    getValue(index: string): any;
    /**
     * Set value of the field.
     *
     * @param value Value to set.
     *
     * @since 1.0.0
     */
    setValue(value: any, index: string): void;
    /**
     * Set values of the field.
     *
     * @param values All values of the field.
     *
     * @since 1.0.0
     */
    setValues(values: any[]): any[];
    /**
     * Add new value to the field.
     *
     * @param value New value.
     *
     * @since 1.0.0
     */
    addValue(value?: any): void;
    /**
     * Remove value from the field.
     *
     * @param index Index of the value to remove.
     *
     * @since 1.0.0
     */
    removeValue(index: string): void;
    /**
     * Validate field values and set errors.
     *
     * @returns True if field is valid.
     *
     * @since 1.0.0
     */
    validate(): boolean;
}
