import Field from './Field';
import Validations from '../Helpers/Validations';
import { fieldStore } from '../../Stores/FieldStore';
/**
 * SingleField class.
 *
 * @since 1.0.0
 */
export default class SingleField extends Field {
    /**
     * Initializing field.
     *
     * @param fieldData  Field data.
     * @param formValues Form values.
     *
     * @since 1.0.0
     */
    constructor(fieldData, formValues) {
        super(fieldData, formValues);
        if (this.valueDefault !== undefined && this.getValue() === undefined) {
            this.formValues[this.id] = this.valueDefault;
        }
    }
    /**
     * Doing form things and get value of the field.
     *
     * @returns Value of the field.
     *
     * @since 1.0.0
     */
    getValue() {
        return this.formValues[this.id];
    }
    /**
     * Doing form things and g set value of the field.
     *
     * @param value Value to set.
     *
     * @since 1.0.0
     */
    setValue(value) {
        value = this.replace(value); // Auto replacements e.g. for points replace with comma.
        if (this.formValues[this.id] === value) {
            return value;
        }
        this.formValues[this.id] = value;
        this.validate();
        this.updateAssets();
        fieldStore.set(this);
        return value;
    }
    /**
     * Validate field values and set errors.
     *
     * @returns True if field is valid.
     *
     * @since 1.0.0
     */
    validate() {
        let validations = new Validations(this.validations);
        validations.validate(this.getValue());
        this.isValidated = true;
        this.errors = validations.getErrors();
        return this.errors.length === 0;
    }
}
