import CSSClasses from '../Helpers/CSSClasses';
import Conditions from '../Helpers/Conditions';
import MultipleField from '../Fields/MultipleField';
import SingleField from '../Fields/SingleField';
/**
 * Class Fieldset.
 *
 * @since 1.0.0
 */
export default class Fieldset {
    id;
    legend;
    fields = [];
    nextFieldset;
    prevFieldset;
    conditions;
    classes;
    legendClasses;
    fieldsClasses;
    /**
     * Constructor.
     *
     * @param form Form object.
     *
     * @since 1.0.0
     */
    constructor(fieldsetData, formValues = {}) {
        this.id = fieldsetData.id;
        this.legend = fieldsetData.legend;
        this.nextFieldset = fieldsetData.nextFieldset;
        this.prevFieldset = fieldsetData.prevFieldset;
        fieldsetData.fields.forEach((fieldData) => {
            if (fieldData.multiple === true) {
                this.fields.push(new MultipleField(fieldData, formValues));
            }
            else {
                this.fields.push(new SingleField(fieldData, formValues));
            }
        });
        this.conditions = new Conditions(fieldsetData.conditions, formValues);
        this.classes = new CSSClasses(fieldsetData.classes);
        this.legendClasses = new CSSClasses(fieldsetData.legendClasses);
        this.fieldsClasses = new CSSClasses(fieldsetData.fieldsClasses);
    }
    hasNext() {
        return this.nextFieldset !== undefined;
    }
    hasPrev() {
        return this.prevFieldset !== undefined;
    }
}
