/**
 * Conditions class.
 *
 * @since 1.0.0
 */
export default class Conditions {
    conditions;
    formValues;
    /**
     * Constuctor.
     *
     * @param conditions Conditions.
     *
     * @since 1.0.0
     */
    constructor(conditions = [], formValues = {}) {
        this.conditions = conditions;
        this.formValues = formValues;
    }
    /**
     * Checks if conditions are fullfilled.
     *
     * @returns True if fullfilled, false if not.
     *
     * @since 1.0.0
     */
    fullfilled() {
        let fullfillments = [];
        if (this.conditions.length === 0) {
            return true;
        }
        this.conditions.forEach((condition) => {
            let fullfilled = false;
            if (condition.fieldId === undefined || condition.operator === undefined || condition.value === undefined) {
                console.error('Condition is not valid.', condition);
            }
            if (condition.fieldId in this.formValues) {
                console.warn('Field not found in form values.', condition.fieldId);
            }
            let fieldValue = this.formValues[condition.fieldId];
            let compareValue = this.filterCompareValue(condition.value);
            switch (condition.operator) {
                case '==':
                    fullfilled = compareValue == fieldValue;
                    break;
                case '!=':
                    fullfilled = compareValue != fieldValue;
                    break;
                case '>':
                    fullfilled = parseFloat(fieldValue) > parseFloat(compareValue);
                    break;
                case '<':
                    fullfilled = parseFloat(fieldValue) < parseFloat(compareValue);
                    break;
                case '>=':
                    fullfilled = parseFloat(fieldValue) >= parseFloat(compareValue);
                    break;
                case '<=':
                    fullfilled = parseFloat(fieldValue) <= parseFloat(compareValue);
                    break;
                default:
                    console.error('Operator does not exist.', condition.operator);
            }
            fullfillments.push(fullfilled);
        });
        return !fullfillments.includes(false);
    }
    /**
     * Filter compare value.
     *
     * This makes values like "undefined" possible.
     *
     * @param value Value to filter.
     * @returns Filtered value.
     *
     * @since 1.0.0
     */
    filterCompareValue(value) {
        switch (value) {
            case 'undefined':
                return undefined;
            case 'true':
                return true;
            case 'false':
                return false;
            default:
                return value;
        }
    }
}
